@@ -41,7 +41,7 @@ import requests
 from .cache import Cache
 from . import events
 from . import config
-from .exceptions import SoCoUPnPException, UnknownSoCoException
+from .exceptions import NotSupportedException, SoCoUPnPException, UnknownSoCoException
 from .utils import prettify
 from .xml import XML, illegal_xml_re
 
@@ -473,7 +473,7 @@ class Service:
             return result
         # Cache miss, so go ahead and make a network call
         headers, body = self.build_command(action, args)
-        log.info("Sending %s %s to %s", action, args, self.soco.ip_address)
+        log.debug("Sending %s %s to %s", action, args, self.soco.ip_address)
         log.debug("Sending %s, %s", headers, prettify(body))
         # Convert the body to bytes, and send it.
         response = requests.post(
@@ -485,7 +485,7 @@ class Service:
 
         log.debug("Received %s, %s", response.headers, response.text)
         status = response.status_code
-        log.info("Received status %s from %s", status, self.soco.ip_address)
+        log.debug("Received status %s from %s", status, self.soco.ip_address)
         if status == 200:
             # The response is good. Get the output params, and return them.
             # NB an empty dict is a valid result. It just means that no
@@ -496,6 +496,10 @@ class Service:
             # error, since we would want to try a network call again.
             cache.put(result, action, args, timeout=cache_timeout)
             return result
+        elif status == 405:
+            raise NotSupportedException(
+                "{} not supported on {}".format(action, self.soco.ip_address)
+            )
         elif status == 500:
             # Internal server error. UPnP requires this to be returned if the
             # device does not like the action for some reason. The returned
